export function foo() {
    define([
        "require"
    ], function(r) {
        r("lodash");
    });
}
